ADC_AnalogWDGConfTypeDef

Struct ADC_AnalogWDGConfTypeDef 

#[repr(C)]
pub struct ADC_AnalogWDGConfTypeDef { pub WatchdogMode: u32, pub Channel: u32, pub ITMode: FunctionalState, pub HighThreshold: u32, pub LowThreshold: u32, }
@brief Structure definition of ADC analog watchdog @note The setting of these parameters with function HAL_ADC_AnalogWDGConfig() is conditioned to ADC state. ADC state can be either: ADC disabled or ADC enabled without conversion on going on regular group.

Fields

WatchdogMode: u32

< Configures the ADC analog watchdog mode: single/all/none channels. This parameter can be a value of @ref ADC_analog_watchdog_mode.

Channel: u32

< Selects which ADC channel to monitor by analog watchdog. This parameter has an effect only if parameter ‘WatchdogMode’ is configured on single channel. Only 1 channel can be monitored. This parameter can be a value of @ref ADC_channels.

ITMode: FunctionalState

< Specifies whether the analog watchdog is configured in interrupt or polling mode. This parameter can be set to ENABLE or DISABLE

HighThreshold: u32

< Configures the ADC analog watchdog High threshold value. Depending of ADC resolution selected (12, 10, 8 or 6 bits), this parameter must be a number between Min_Data = 0x000 and Max_Data = 0xFFF, 0x3FF, 0xFF or 0x3F respectively.

LowThreshold: u32

< Configures the ADC analog watchdog High threshold value. Depending of ADC resolution selected (12, 10, 8 or 6 bits), this parameter must be a number between Min_Data = 0x000 and Max_Data = 0xFFF, 0x3FF, 0xFF or 0x3F respectively.