#[repr(C)]pub struct FLASH_EraseInitTypeDef {
pub TypeErase: u32,
pub PageAddress: u32,
pub NbPages: u32,
pub SectorAddress: u32,
pub NbSectors: u32,
}Expand description
@brief FLASH Erase structure definition
Fields
TypeErase: u32< Mass erase or page erase. This parameter can be a value of @ref FLASH_Type_Erase
PageAddress: u32< PageAdress: Initial FLASH page address to erase when mass erase and sector erase is disabled This parameter must be a number between Min_Data = FLASH_BASE and Max_Data = FLASH_END
NbPages: u32< Number of pages to be erased. This parameter must be a value between 1 and (FLASH_PAGE_NB - value of initial page)
SectorAddress: u32< PageAdress: Initial FLASH page address to erase when mass erase and page erase is disabled This parameter must be a number between Min_Data = FLASH_BASE and Max_Data = FLASH_BANK1_END
NbSectors: u32< Number of sectors to be erased. This parameter must be a value between 1 and (FLASH_SECTOR_NB - value of initial sector)