#[repr(C)]pub struct TIM_MasterConfigTypeDef {
pub MasterOutputTrigger: u32,
pub MasterSlaveMode: u32,
}Expand description
@brief TIM Master configuration Structure definition
Fields
MasterOutputTrigger: u32< Trigger output (TRGO) selection This parameter can be a value of @ref TIM_Master_Mode_Selection
MasterSlaveMode: u32< Master/slave mode selection This parameter can be a value of @ref TIM_Master_Slave_Mode @note When the Master/slave mode is enabled, the effect of an event on the trigger input (TRGI) is delayed to allow a perfect synchronization between the current timer and its slaves (through TRGO). It is not mandatory in case of timer synchronization mode.