#[repr(C)]pub struct TIM_OC_InitTypeDef {
pub OCMode: u32,
pub Pulse: u32,
pub OCPolarity: u32,
pub OCNPolarity: u32,
pub OCFastMode: u32,
pub OCIdleState: u32,
pub OCNIdleState: u32,
}Expand description
@brief TIM Output Compare Configuration Structure definition
Fields
OCMode: u32< Specifies the TIM mode. This parameter can be a value of @ref TIM_Output_Compare_and_PWM_modes
Pulse: u32< Specifies the pulse value to be loaded into the Capture Compare Register. This parameter can be a number between Min_Data = 0x0000 and Max_Data = 0xFFFF
OCPolarity: u32< Specifies the output polarity. This parameter can be a value of @ref TIM_Output_Compare_Polarity
OCNPolarity: u32< Specifies the complementary output polarity. This parameter can be a value of @ref TIM_Output_Compare_N_Polarity @note This parameter is valid only for timer instances supporting break feature.
OCFastMode: u32< Specifies the Fast mode state. This parameter can be a value of @ref TIM_Output_Fast_State @note This parameter is valid only in PWM1 and PWM2 mode.
OCIdleState: u32< Specifies the TIM Output Compare pin state during Idle state. This parameter can be a value of @ref TIM_Output_Compare_Idle_State @note This parameter is valid only for timer instances supporting break feature.
OCNIdleState: u32< Specifies the TIM Output Compare pin state during Idle state. This parameter can be a value of @ref TIM_Output_Compare_N_Idle_State @note This parameter is valid only for timer instances supporting break feature.